# frostypy - an engineering toolkit for frost growth properties and correlations

![Python Logo](https://www.python.org/static/community_logos/python-logo.png "Sample inline image")

This package is used for compiling frost growth correlations.

A sample project that exists as an aid to the [Python Packaging User
Guide][packaging guide]'s [Tutorial on Packaging and Distributing
Projects][distribution tutorial].


[packaging guide]: https://packaging.python.org
[distribution tutorial]: https://packaging.python.org/tutorials/packaging-projects/
